@@ -7,6 +7,7 @@ use std::collections::BTreeMap;
 use std::fmt;
 
 use k8s_openapi::apimachinery;
+use k8s_openapi::ByteString;
 use kube::api;
 use kube::config;
 use kube::{Resource, ResourceExt};
@@ -108,6 +109,31 @@ impl Kubectl {
 
         Ok(object)
     }
+
+    pub async fn ensure_default_namespaced_k_is_installed<K>(
+        &self,
+        mut object: K,
+    ) -> kube::Result<K>
+    where
+        K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
+        <K as kube::Resource>::DynamicType: Default,
+    {
+        let name = object.name();
+        let objects = self.default_namespaced_api::<K>();
+        if let Ok(existing) = objects.get(&name).await {
+            object.meta_mut().resource_version = existing.resource_version();
+        }
+
+        let pp = self.post_params();
+
+        let object = if object.resource_version().is_some() {
+            objects.replace(&name, &pp, &object).await?
+        } else {
+            objects.create(&pp, &object).await?
+        };
+
+        Ok(object)
+    }
 }
 
 impl fmt::Debug for Kubectl {
