@@ -34,8 +34,10 @@ pub use ext::PolicyRuleExt;
 pub use ext::ResourceExt;
 pub use ext::RoleBindingExt;
 pub use ext::RoleExt;
+pub use ext::RoleRefExt;
 pub use ext::SecretExt;
 pub use ext::ServiceAccountExt;
+pub use ext::SubjectExt;
 
 pub use kubectl::Kubectl;
 
